# openapi-client
Documentation for the Montelo API.

The `openapi_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with openapi-client,
you can run the following:

```python

import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:3001
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "http://localhost:3001"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearer
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ApiKeyApi(api_client)

    try:
        api_response = api_instance.api_key_controller_get_api_keys_for_project()
        print("The response of ApiKeyApi->api_key_controller_get_api_keys_for_project:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApiKeyApi->api_key_controller_get_api_keys_for_project: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:3001*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiKeyApi* | [**api_key_controller_get_api_keys_for_project**](openapi_client/docs/ApiKeyApi.md#api_key_controller_get_api_keys_for_project) | **GET** /api-keys | 
*ApiKeyApi* | [**api_key_controller_reveal_one**](openapi_client/docs/ApiKeyApi.md#api_key_controller_reveal_one) | **GET** /api-keys/{apiKeyId} | 
*ApiKeyApi* | [**api_key_controller_rotate_one**](openapi_client/docs/ApiKeyApi.md#api_key_controller_rotate_one) | **POST** /api-keys/{apiKeyId} | 
*DatapointApi* | [**datapoint_controller_batch_create_datapoint**](openapi_client/docs/DatapointApi.md#datapoint_controller_batch_create_datapoint) | **POST** /dataset/{datasetId}/datapoint/batch | 
*DatapointApi* | [**datapoint_controller_create_datapoint**](openapi_client/docs/DatapointApi.md#datapoint_controller_create_datapoint) | **POST** /dataset/{datasetId}/datapoint | 
*DatapointApi* | [**datapoint_controller_delete_datapoint**](openapi_client/docs/DatapointApi.md#datapoint_controller_delete_datapoint) | **DELETE** /datapoint/{datapointId} | 
*DatapointRunApi* | [**datapoint_run_controller_create_datapoint_run**](openapi_client/docs/DatapointRunApi.md#datapoint_run_controller_create_datapoint_run) | **POST** /datapoint-run | 
*DatapointRunApi* | [**datapoint_run_controller_get_datapoint_with_experiment**](openapi_client/docs/DatapointRunApi.md#datapoint_run_controller_get_datapoint_with_experiment) | **GET** /datapoint-run/{datapointRunId} | 
*DatapointRunApi* | [**datapoint_run_controller_update_datapoint_run**](openapi_client/docs/DatapointRunApi.md#datapoint_run_controller_update_datapoint_run) | **PATCH** /datapoint-run | 
*DatasetApi* | [**dataset_controller_create_dataset**](openapi_client/docs/DatasetApi.md#dataset_controller_create_dataset) | **POST** /dataset | 
*DatasetApi* | [**dataset_controller_delete_dataset**](openapi_client/docs/DatasetApi.md#dataset_controller_delete_dataset) | **DELETE** /dataset/{datasetId} | 
*DatasetApi* | [**dataset_controller_download_dataset**](openapi_client/docs/DatasetApi.md#dataset_controller_download_dataset) | **GET** /dataset/{datasetId}/download | 
*DatasetApi* | [**dataset_controller_get_all_datasets_for_env**](openapi_client/docs/DatasetApi.md#dataset_controller_get_all_datasets_for_env) | **GET** /env/{envId}/dataset | 
*DatasetApi* | [**dataset_controller_get_dataset_recent_experiments**](openapi_client/docs/DatasetApi.md#dataset_controller_get_dataset_recent_experiments) | **GET** /dataset/{datasetId}/experiments | 
*DatasetApi* | [**dataset_controller_get_dataset_with_datapoints**](openapi_client/docs/DatasetApi.md#dataset_controller_get_dataset_with_datapoints) | **GET** /dataset/{datasetId} | 
*EnvironmentApi* | [**environment_controller_create_env**](openapi_client/docs/EnvironmentApi.md#environment_controller_create_env) | **POST** /env | 
*EnvironmentApi* | [**environment_controller_get_env**](openapi_client/docs/EnvironmentApi.md#environment_controller_get_env) | **GET** /env/{envId} | 
*ExperimentApi* | [**experiment_controller_create**](openapi_client/docs/ExperimentApi.md#experiment_controller_create) | **POST** /dataset/{datasetId}/experiment | 
*ExperimentApi* | [**experiment_controller_get_analytics_for_experiment**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_analytics_for_experiment) | **GET** /experiment/{experimentId}/analytics | 
*ExperimentApi* | [**experiment_controller_get_evals_for_experiment**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_evals_for_experiment) | **GET** /experiment/{experimentId}/evals | 
*ExperimentApi* | [**experiment_controller_get_experiments_for_dataset**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_experiments_for_dataset) | **GET** /dataset/{datasetId}/experiment | 
*ExperimentApi* | [**experiment_controller_get_paginated_datapoints_for_experiment**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_paginated_datapoints_for_experiment) | **GET** /experiment/{experimentId}/datapoints | 
*ExperimentApi* | [**experiment_controller_get_paginated_experiment_with_datapoint_runs**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_paginated_experiment_with_datapoint_runs) | **GET** /experiment/{experimentId} | 
*ExperimentApi* | [**experiment_controller_get_paginated_experiments_for_environment**](openapi_client/docs/ExperimentApi.md#experiment_controller_get_paginated_experiments_for_environment) | **GET** /env/{envId}/experiment | 
*FineTuningApi* | [**finetune_controller_create_cohere_fine_tune**](openapi_client/docs/FineTuningApi.md#finetune_controller_create_cohere_fine_tune) | **POST** /dataset/{datasetId}/fine-tune/cohere | 
*FineTuningApi* | [**finetune_controller_create_fine_tune**](openapi_client/docs/FineTuningApi.md#finetune_controller_create_fine_tune) | **POST** /dataset/{datasetId}/fine-tune | 
*FineTuningApi* | [**finetune_controller_create_open_ai_fine_tune**](openapi_client/docs/FineTuningApi.md#finetune_controller_create_open_ai_fine_tune) | **POST** /dataset/{datasetId}/fine-tune/openai | 
*FineTuningApi* | [**finetune_controller_get_fine_tunes_for_env**](openapi_client/docs/FineTuningApi.md#finetune_controller_get_fine_tunes_for_env) | **GET** /env/{envId}/fine-tune | 
*FineTuningApi* | [**finetune_controller_get_finetune_cost_estimate**](openapi_client/docs/FineTuningApi.md#finetune_controller_get_finetune_cost_estimate) | **GET** /dataset/{datasetId}/fine-tune/cost-estimate | 
*GenerateApi* | [**generate_controller_generate**](openapi_client/docs/GenerateApi.md#generate_controller_generate) | **POST** /generate | 
*HealthApi* | [**health_controller_check**](openapi_client/docs/HealthApi.md#health_controller_check) | **GET** /health | 
*InferenceApi* | [**inference_controller_inference**](openapi_client/docs/InferenceApi.md#inference_controller_inference) | **POST** /inference/{model} | 
*OrganizationApi* | [**organization_controller_create_project**](openapi_client/docs/OrganizationApi.md#organization_controller_create_project) | **POST** /organization | 
*OrganizationApi* | [**organization_controller_get_projects_for_org**](openapi_client/docs/OrganizationApi.md#organization_controller_get_projects_for_org) | **GET** /organization | 
*PaymentApi* | [**payment_controller_create_checkout_session**](openapi_client/docs/PaymentApi.md#payment_controller_create_checkout_session) | **POST** /payment/checkout | 
*PaymentApi* | [**payment_controller_create_customer**](openapi_client/docs/PaymentApi.md#payment_controller_create_customer) | **POST** /payment/customer | 
*PaymentApi* | [**payment_controller_get_user_subscription**](openapi_client/docs/PaymentApi.md#payment_controller_get_user_subscription) | **GET** /payment/subscription | 
*ProjectApi* | [**project_controller_delete_project**](openapi_client/docs/ProjectApi.md#project_controller_delete_project) | **DELETE** /project | 
*ProjectApi* | [**project_controller_get_all_projects**](openapi_client/docs/ProjectApi.md#project_controller_get_all_projects) | **GET** /project/all | 
*ProjectApi* | [**project_controller_get_project**](openapi_client/docs/ProjectApi.md#project_controller_get_project) | **GET** /project | 
*ProjectApi* | [**project_controller_set_cohere_api_key**](openapi_client/docs/ProjectApi.md#project_controller_set_cohere_api_key) | **POST** /project/cohere-api-key | 
*ProjectApi* | [**project_controller_set_open_aiapi_key**](openapi_client/docs/ProjectApi.md#project_controller_set_open_aiapi_key) | **POST** /project/openai-api-key | 
*DefaultApi* | [**webhook_controller_clerk_get_webhook**](openapi_client/docs/DefaultApi.md#webhook_controller_clerk_get_webhook) | **GET** /webhook/clerk | 
*DefaultApi* | [**webhook_controller_clerk_post_webhook**](openapi_client/docs/DefaultApi.md#webhook_controller_clerk_post_webhook) | **POST** /webhook/clerk | 
*DefaultApi* | [**webhook_controller_stripe_post_webhook**](openapi_client/docs/DefaultApi.md#webhook_controller_stripe_post_webhook) | **POST** /webhook/stripe | 


## Documentation For Models

 - [AddToDatasetInput](openapi_client/docs/AddToDatasetInput.md)
 - [ApiKeyWithEnvDto](openapi_client/docs/ApiKeyWithEnvDto.md)
 - [BatchAddToDatasetInput](openapi_client/docs/BatchAddToDatasetInput.md)
 - [ChatCompletionDto](openapi_client/docs/ChatCompletionDto.md)
 - [ChoiceDto](openapi_client/docs/ChoiceDto.md)
 - [Config](openapi_client/docs/Config.md)
 - [CreateDatapointRunInput](openapi_client/docs/CreateDatapointRunInput.md)
 - [CreateDatasetInput](openapi_client/docs/CreateDatasetInput.md)
 - [CreateEnvInput](openapi_client/docs/CreateEnvInput.md)
 - [CreateExperimentInput](openapi_client/docs/CreateExperimentInput.md)
 - [CreateFineTuneInput](openapi_client/docs/CreateFineTuneInput.md)
 - [CreateProjectInput](openapi_client/docs/CreateProjectInput.md)
 - [DatapointDto](openapi_client/docs/DatapointDto.md)
 - [DatapointRunDto](openapi_client/docs/DatapointRunDto.md)
 - [DatapointRunWithExperimentDto](openapi_client/docs/DatapointRunWithExperimentDto.md)
 - [DatasetDto](openapi_client/docs/DatasetDto.md)
 - [DatasetInput](openapi_client/docs/DatasetInput.md)
 - [EnvironmentDto](openapi_client/docs/EnvironmentDto.md)
 - [ExperimentAnalyticsDto](openapi_client/docs/ExperimentAnalyticsDto.md)
 - [ExperimentDto](openapi_client/docs/ExperimentDto.md)
 - [ExperimentEvalsChartDto](openapi_client/docs/ExperimentEvalsChartDto.md)
 - [ExperimentEvalsDto](openapi_client/docs/ExperimentEvalsDto.md)
 - [ExperimentEvalsValueDto](openapi_client/docs/ExperimentEvalsValueDto.md)
 - [ExperimentWithDatapointRunsDto](openapi_client/docs/ExperimentWithDatapointRunsDto.md)
 - [ExperimentWithDatapointsDto](openapi_client/docs/ExperimentWithDatapointsDto.md)
 - [FineTuneCohereInput](openapi_client/docs/FineTuneCohereInput.md)
 - [FineTuneDto](openapi_client/docs/FineTuneDto.md)
 - [FineTuneOpenaiInput](openapi_client/docs/FineTuneOpenaiInput.md)
 - [FineTuneWithDatasetDto](openapi_client/docs/FineTuneWithDatasetDto.md)
 - [FinetuneCostEstimateDto](openapi_client/docs/FinetuneCostEstimateDto.md)
 - [FullDatapointRunDto](openapi_client/docs/FullDatapointRunDto.md)
 - [FullDatasetDto](openapi_client/docs/FullDatasetDto.md)
 - [FullDatasetWithCountDto](openapi_client/docs/FullDatasetWithCountDto.md)
 - [FullProjectDto](openapi_client/docs/FullProjectDto.md)
 - [GenerateInput](openapi_client/docs/GenerateInput.md)
 - [GenerationInput](openapi_client/docs/GenerationInput.md)
 - [HealthControllerCheck200Response](openapi_client/docs/HealthControllerCheck200Response.md)
 - [HealthControllerCheck200ResponseInfoValue](openapi_client/docs/HealthControllerCheck200ResponseInfoValue.md)
 - [HealthControllerCheck503Response](openapi_client/docs/HealthControllerCheck503Response.md)
 - [InferenceInput](openapi_client/docs/InferenceInput.md)
 - [MessageDto](openapi_client/docs/MessageDto.md)
 - [ModelConfig](openapi_client/docs/ModelConfig.md)
 - [PaginatedExperimentWithDatapointRunsDto](openapi_client/docs/PaginatedExperimentWithDatapointRunsDto.md)
 - [PaginatedExperimentWithDatapointsDto](openapi_client/docs/PaginatedExperimentWithDatapointsDto.md)
 - [PaginatedExperimentsDto](openapi_client/docs/PaginatedExperimentsDto.md)
 - [ProjectDto](openapi_client/docs/ProjectDto.md)
 - [Prompt](openapi_client/docs/Prompt.md)
 - [ResponseFormatDto](openapi_client/docs/ResponseFormatDto.md)
 - [SetCohereApiKeyInput](openapi_client/docs/SetCohereApiKeyInput.md)
 - [SetOpenaiApiKeyInput](openapi_client/docs/SetOpenaiApiKeyInput.md)
 - [SubscriptionDto](openapi_client/docs/SubscriptionDto.md)
 - [SuccessDto](openapi_client/docs/SuccessDto.md)
 - [ToolDto](openapi_client/docs/ToolDto.md)
 - [ToolFunctionDto](openapi_client/docs/ToolFunctionDto.md)
 - [UpdateDatapointRunInput](openapi_client/docs/UpdateDatapointRunInput.md)
 - [UsageDataDto](openapi_client/docs/UsageDataDto.md)
 - [VariablesInput](openapi_client/docs/VariablesInput.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer"></a>
### bearer

- **Type**: Bearer authentication (JWT)


## Author




